Documentation
¶
Index ¶
- Constants
- Variables
- type Artifact
- func (*Artifact) Descriptor() ([]byte, []int)deprecated
- func (x *Artifact) GetCallId() string
- func (x *Artifact) GetData() []byte
- func (x *Artifact) GetKind() string
- func (x *Artifact) GetMediaType() string
- func (x *Artifact) GetResultId() string
- func (x *Artifact) GetTarget() string
- func (x *Artifact) GetTimestamp() *timestamppb.Timestamp
- func (x *Artifact) GetTool() string
- func (*Artifact) ProtoMessage()
- func (x *Artifact) ProtoReflect() protoreflect.Message
- func (x *Artifact) Reset()
- func (x *Artifact) String() string
- type Call
- type Loot
- func (*Loot) Descriptor() ([]byte, []int)deprecated
- func (x *Loot) GetCallId() string
- func (x *Loot) GetDescription() string
- func (x *Loot) GetKind() string
- func (x *Loot) GetPriority() string
- func (x *Loot) GetResultId() string
- func (x *Loot) GetTags() []string
- func (x *Loot) GetTarget() string
- func (x *Loot) GetTool() string
- func (x *Loot) GetVerificationStatus() string
- func (*Loot) ProtoMessage()
- func (x *Loot) ProtoReflect() protoreflect.Message
- func (x *Loot) Reset()
- func (x *Loot) String() string
- type Progress
- func (*Progress) Descriptor() ([]byte, []int)deprecated
- func (x *Progress) GetCallId() string
- func (x *Progress) GetTarget() string
- func (x *Progress) GetText() string
- func (x *Progress) GetTimestamp() *timestamppb.Timestamp
- func (x *Progress) GetTool() string
- func (*Progress) ProtoMessage()
- func (x *Progress) ProtoReflect() protoreflect.Message
- func (x *Progress) Reset()
- func (x *Progress) String() string
- type ProtocolMessage
- func (*ProtocolMessage) Descriptor() ([]byte, []int)deprecated
- func (x *ProtocolMessage) GetArtifact() *Artifact
- func (x *ProtocolMessage) GetCall() *Call
- func (x *ProtocolMessage) GetLoot() *Loot
- func (x *ProtocolMessage) GetMessage() isProtocolMessage_Message
- func (x *ProtocolMessage) GetProgress() *Progress
- func (*ProtocolMessage) ProtoMessage()
- func (x *ProtocolMessage) ProtoReflect() protoreflect.Message
- func (x *ProtocolMessage) Reset()
- func (x *ProtocolMessage) String() string
- type ProtocolMessage_Artifact
- type ProtocolMessage_Call
- type ProtocolMessage_Loot
- type ProtocolMessage_Progress
Constants ¶
const ( ArtifactKindService = "service" ArtifactKindWeb = "web" ArtifactKindWeakpass = "weakpass" ArtifactKindVuln = "vuln" )
Variables ¶
var File_aop_tool_protocol_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Artifact ¶
type Artifact struct {
Tool string `protobuf:"bytes,1,opt,name=tool,proto3" json:"tool,omitempty"`
Kind string `protobuf:"bytes,2,opt,name=kind,proto3" json:"kind,omitempty"`
Target string `protobuf:"bytes,3,opt,name=target,proto3" json:"target,omitempty"`
Data []byte `protobuf:"bytes,4,opt,name=data,proto3" json:"data,omitempty"`
MediaType string `protobuf:"bytes,5,opt,name=media_type,json=mediaType,proto3" json:"media_type,omitempty"`
Timestamp *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
CallId string `protobuf:"bytes,7,opt,name=call_id,json=callId,proto3" json:"call_id,omitempty"`
ResultId string `protobuf:"bytes,8,opt,name=result_id,json=resultId,proto3" json:"result_id,omitempty"`
// contains filtered or unexported fields
}
Artifact carries one scanner-native structured record. Nodes remain thin: only the server normalizes these records into canonical SCO documents.
func (*Artifact) Descriptor
deprecated
func (*Artifact) GetMediaType ¶
func (*Artifact) GetResultId ¶
func (*Artifact) GetTimestamp ¶
func (x *Artifact) GetTimestamp() *timestamppb.Timestamp
func (*Artifact) ProtoMessage ¶
func (*Artifact) ProtoMessage()
func (*Artifact) ProtoReflect ¶
func (x *Artifact) ProtoReflect() protoreflect.Message
type Call ¶
type Call struct {
SessionId string `protobuf:"bytes,1,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
TurnId string `protobuf:"bytes,2,opt,name=turn_id,json=turnId,proto3" json:"turn_id,omitempty"`
Call *aop.ToolCall `protobuf:"bytes,3,opt,name=call,proto3" json:"call,omitempty"`
// contains filtered or unexported fields
}
func (*Call) Descriptor
deprecated
func (*Call) GetSessionId ¶
func (*Call) ProtoMessage ¶
func (*Call) ProtoMessage()
func (*Call) ProtoReflect ¶
func (x *Call) ProtoReflect() protoreflect.Message
type Loot ¶
type Loot struct {
ResultId string `protobuf:"bytes,1,opt,name=result_id,json=resultId,proto3" json:"result_id,omitempty"`
Tool string `protobuf:"bytes,2,opt,name=tool,proto3" json:"tool,omitempty"`
Kind string `protobuf:"bytes,3,opt,name=kind,proto3" json:"kind,omitempty"`
Target string `protobuf:"bytes,4,opt,name=target,proto3" json:"target,omitempty"`
Priority string `protobuf:"bytes,5,opt,name=priority,proto3" json:"priority,omitempty"`
Tags []string `protobuf:"bytes,6,rep,name=tags,proto3" json:"tags,omitempty"`
Description string `protobuf:"bytes,7,opt,name=description,proto3" json:"description,omitempty"`
VerificationStatus string `protobuf:"bytes,8,opt,name=verification_status,json=verificationStatus,proto3" json:"verification_status,omitempty"`
CallId string `protobuf:"bytes,9,opt,name=call_id,json=callId,proto3" json:"call_id,omitempty"`
// contains filtered or unexported fields
}
Loot marks a scanner-native artifact as valuable without replacing or duplicating its evidence. result_id joins the marker back to Artifact.
func (*Loot) Descriptor
deprecated
func (*Loot) GetDescription ¶
func (*Loot) GetPriority ¶
func (*Loot) GetResultId ¶
func (*Loot) GetVerificationStatus ¶
func (*Loot) ProtoMessage ¶
func (*Loot) ProtoMessage()
func (*Loot) ProtoReflect ¶
func (x *Loot) ProtoReflect() protoreflect.Message
type Progress ¶
type Progress struct {
Tool string `protobuf:"bytes,1,opt,name=tool,proto3" json:"tool,omitempty"`
Target string `protobuf:"bytes,3,opt,name=target,proto3" json:"target,omitempty"`
Timestamp *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
Text string `protobuf:"bytes,6,opt,name=text,proto3" json:"text,omitempty"`
CallId string `protobuf:"bytes,7,opt,name=call_id,json=callId,proto3" json:"call_id,omitempty"`
// contains filtered or unexported fields
}
func (*Progress) Descriptor
deprecated
func (*Progress) GetTimestamp ¶
func (x *Progress) GetTimestamp() *timestamppb.Timestamp
func (*Progress) ProtoMessage ¶
func (*Progress) ProtoMessage()
func (*Progress) ProtoReflect ¶
func (x *Progress) ProtoReflect() protoreflect.Message
type ProtocolMessage ¶
type ProtocolMessage struct {
// Types that are valid to be assigned to Message:
//
// *ProtocolMessage_Progress
// *ProtocolMessage_Call
// *ProtocolMessage_Artifact
// *ProtocolMessage_Loot
Message isProtocolMessage_Message `protobuf_oneof:"message"`
// contains filtered or unexported fields
}
func (*ProtocolMessage) Descriptor
deprecated
func (*ProtocolMessage) Descriptor() ([]byte, []int)
Deprecated: Use ProtocolMessage.ProtoReflect.Descriptor instead.
func (*ProtocolMessage) GetArtifact ¶
func (x *ProtocolMessage) GetArtifact() *Artifact
func (*ProtocolMessage) GetCall ¶
func (x *ProtocolMessage) GetCall() *Call
func (*ProtocolMessage) GetLoot ¶
func (x *ProtocolMessage) GetLoot() *Loot
func (*ProtocolMessage) GetMessage ¶
func (x *ProtocolMessage) GetMessage() isProtocolMessage_Message
func (*ProtocolMessage) GetProgress ¶
func (x *ProtocolMessage) GetProgress() *Progress
func (*ProtocolMessage) ProtoMessage ¶
func (*ProtocolMessage) ProtoMessage()
func (*ProtocolMessage) ProtoReflect ¶
func (x *ProtocolMessage) ProtoReflect() protoreflect.Message
func (*ProtocolMessage) Reset ¶
func (x *ProtocolMessage) Reset()
func (*ProtocolMessage) String ¶
func (x *ProtocolMessage) String() string
type ProtocolMessage_Artifact ¶
type ProtocolMessage_Artifact struct {
Artifact *Artifact `protobuf:"bytes,12,opt,name=artifact,proto3,oneof"`
}
type ProtocolMessage_Call ¶
type ProtocolMessage_Call struct {
Call *Call `protobuf:"bytes,11,opt,name=call,proto3,oneof"`
}
type ProtocolMessage_Loot ¶
type ProtocolMessage_Loot struct {
Loot *Loot `protobuf:"bytes,13,opt,name=loot,proto3,oneof"`
}
type ProtocolMessage_Progress ¶
type ProtocolMessage_Progress struct {
Progress *Progress `protobuf:"bytes,10,opt,name=progress,proto3,oneof"`
}
Click to show internal directories.
Click to hide internal directories.